==> gnome-shell-2.31.5.tar.bz2: gnome-shell-2.31.5/src/shell-enum-types.c <==

/* Generated data (by glib-mkenums) */

#include "shell-enum-types.h"
/* enumerations from "shell-app.h" */
#include "shell-app.h"
GType
shell_app_state_get_type(void) {
  static GType enum_type_id = 0;
  if (G_UNLIKELY (!enum_type_id))
    {
      static const GEnumValue values[] = {
        { SHELL_APP_STATE_STOPPED, "SHELL_APP_STATE_STOPPED", "stopped" },
        { SHELL_APP_STATE_STARTING, "SHELL_APP_STATE_STARTING", "starting" },
        { SHELL_APP_STATE_RUNNING, "SHELL_APP_STATE_RUNNING", "running" },
        { 0, NULL, NULL }
      };
      enum_type_id = g_enum_register_static("ShellAppState", values);
    }
  return enum_type_id;
}
/* enumerations from "shell-drawing.h" */
#include "shell-drawing.h"
GType
shell_pointer_direction_get_type(void) {
  static GType enum_type_id = 0;
  if (G_UNLIKELY (!enum_type_id))
    {
      static const GEnumValue values[] = {
        { SHELL_POINTER_UP, "SHELL_POINTER_UP", "up" },
        { SHELL_POINTER_RIGHT, "SHELL_POINTER_RIGHT", "right" },
        { SHELL_POINTER_DOWN, "SHELL_POINTER_DOWN", "down" },
        { SHELL_POINTER_LEFT, "SHELL_POINTER_LEFT", "left" },
        { 0, NULL, NULL }
      };
      enum_type_id = g_enum_register_static("ShellPointerDirection", values);
    }
  return enum_type_id;
}
/* enumerations from "shell-global.h" */
#include "shell-global.h"
GType
shell_stage_input_mode_get_type(void) {
  static GType enum_type_id = 0;
  if (G_UNLIKELY (!enum_type_id))
    {
      static const GEnumValue values[] = {
        { SHELL_STAGE_INPUT_MODE_NONREACTIVE, "SHELL_STAGE_INPUT_MODE_NONREACTIVE", "nonreactive" },
        { SHELL_STAGE_INPUT_MODE_NORMAL, "SHELL_STAGE_INPUT_MODE_NORMAL", "normal" },
        { SHELL_STAGE_INPUT_MODE_FULLSCREEN, "SHELL_STAGE_INPUT_MODE_FULLSCREEN", "fullscreen" },
        { 0, NULL, NULL }
      };
      enum_type_id = g_enum_register_static("ShellStageInputMode", values);
    }
  return enum_type_id;
}

/* Generated data ends here */

==> gnome-shell-2.91.1.tar.bz2: gnome-shell-2.91.1/src/shell-enum-types.c <==

/* Generated data (by glib-mkenums) */

#include "shell-enum-types.h"
/* enumerations from "shell-app.h" */
#include "shell-app.h"
GType
shell_app_state_get_type(void) {
  static GType enum_type_id = 0;
  if (G_UNLIKELY (!enum_type_id))
    {
      static const GEnumValue values[] = {
        { SHELL_APP_STATE_STOPPED, "SHELL_APP_STATE_STOPPED", "stopped" },
        { SHELL_APP_STATE_STARTING, "SHELL_APP_STATE_STARTING", "starting" },
        { SHELL_APP_STATE_RUNNING, "SHELL_APP_STATE_RUNNING", "running" },
        { 0, NULL, NULL }
      };
      enum_type_id = g_enum_register_static("ShellAppState", values);
    }
  return enum_type_id;
}
/* enumerations from "shell-drawing.h" */
#include "shell-drawing.h"
GType
shell_pointer_direction_get_type(void) {
  static GType enum_type_id = 0;
  if (G_UNLIKELY (!enum_type_id))
    {
      static const GEnumValue values[] = {
        { SHELL_POINTER_UP, "SHELL_POINTER_UP", "up" },
        { SHELL_POINTER_RIGHT, "SHELL_POINTER_RIGHT", "right" },
        { SHELL_POINTER_DOWN, "SHELL_POINTER_DOWN", "down" },
        { SHELL_POINTER_LEFT, "SHELL_POINTER_LEFT", "left" },
        { 0, NULL, NULL }
      };
      enum_type_id = g_enum_register_static("ShellPointerDirection", values);
    }
  return enum_type_id;
}
/* enumerations from "shell-global.h" */
#include "shell-global.h"
GType
shell_cursor_get_type(void) {
  static GType enum_type_id = 0;
  if (G_UNLIKELY (!enum_type_id))
    {
      static const GEnumValue values[] = {
        { SHELL_CURSOR_DND_IN_DRAG, "SHELL_CURSOR_DND_IN_DRAG", "in-drag" },
        { SHELL_CURSOR_DND_UNSUPPORTED_TARGET, "SHELL_CURSOR_DND_UNSUPPORTED_TARGET", "unsupported-target" },
        { SHELL_CURSOR_DND_MOVE, "SHELL_CURSOR_DND_MOVE", "move" },
        { SHELL_CURSOR_DND_COPY, "SHELL_CURSOR_DND_COPY", "copy" },
        { 0, NULL, NULL }
      };
      enum_type_id = g_enum_register_static("ShellCursor", values);
    }
  return enum_type_id;
}
GType
shell_stage_input_mode_get_type(void) {
  static GType enum_type_id = 0;
  if (G_UNLIKELY (!enum_type_id))
    {
      static const GEnumValue values[] = {
        { SHELL_STAGE_INPUT_MODE_NONREACTIVE, "SHELL_STAGE_INPUT_MODE_NONREACTIVE", "nonreactive" },
        { SHELL_STAGE_INPUT_MODE_NORMAL, "SHELL_STAGE_INPUT_MODE_NORMAL", "normal" },
        { SHELL_STAGE_INPUT_MODE_FOCUSED, "SHELL_STAGE_INPUT_MODE_FOCUSED", "focused" },
        { SHELL_STAGE_INPUT_MODE_FULLSCREEN, "SHELL_STAGE_INPUT_MODE_FULLSCREEN", "fullscreen" },
        { 0, NULL, NULL }
      };
      enum_type_id = g_enum_register_static("ShellStageInputMode", values);
    }
  return enum_type_id;
}

/* Generated data ends here */
